==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/acl/lang/sr/lang.php <==
<?php
/**
 * serbian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Filip Brcic <brcha@users.sourceforge.net>
 * @author Иван Петровић petrovicivan@ubuntusrbija.org
 */
$lang['admin_acl']             = 'Управљање листом контроле приступа';
$lang['acl_group']             = 'Група';
$lang['acl_user']              = 'Корисник';
$lang['acl_perms']             = 'Дозволе за';
$lang['page']                  = 'Страница';
$lang['namespace']             = 'Именски простор';
$lang['btn_select']            = 'Одабери';
$lang['p_user_id']             = 'Корисник <b class="acluser">%s</b> тренутно има следеће дозволе за ову страницу <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Корисник <b class="acluser">%s</b> тренутно има следеће дозволе за овај именски простор <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Чланови групе <b class="acluser">%s</b> тренутно имају следеће дозволе за ову страницу <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Чланови групе <b class="acluser">%s</b> тренутно имају следеће дозволе за овај именски простор <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Молим Вас <b>унесите корисника или групу</b> у формулар изнад да бисте приказали или изменили дозволе за страницу <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Молим Вас <b>унесите корисника или групу</b> у формулар изнад да бисте приказали или изменили дозволе за именски простор <b class="aclpage">%s</b>.';
$lang['p_inherited']           = 'Напомена: Ове дозволе се не постављају експлицитно већ само тамо где се не сударају са осталим групама или вишем иманском простору.';
$lang['p_isadmin']             = 'Напомена: Одабран корисник или група има увек пуне дозволе јер је постављен за суперкорисника.';
$lang['current']               = 'Тренутна правила проступа';
$lang['where']                 = 'Страница/Именски простор';
$lang['who']                   = 'Корисник/Група';
$lang['perm']                  = 'Дозволе';
$lang['acl_perm0']             = 'Ништа';
$lang['acl_perm1']             = 'Читање';
$lang['acl_perm2']             = 'Измена';
$lang['acl_perm4']             = 'Прављење';
$lang['acl_perm8']             = 'Слање';
$lang['acl_perm16']            = 'Брисање';
$lang['acl_new']               = 'Додај нови унос';
$lang['acl_mod']               = 'Измени унос';

==> dokuwiki_0.0.20160626.a.orig.tar.gz: dokuwiki-2016-06-26a/lib/plugins/acl/lang/sr/lang.php <==
<?php
/**
 * serbian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Filip Brcic <brcha@users.sourceforge.net>
 * @author Иван Петровић petrovicivan@ubuntusrbija.org
 * @author Ivan Petrovic <petrovicivan@ubuntusrbija.org>
 * @author Miroslav Šolti <solti.miroslav@gmail.com>
 */
$lang['admin_acl']             = 'Управљање листом контроле приступа';
$lang['acl_group']             = 'Група:';
$lang['acl_user']              = 'Корисник:';
$lang['acl_perms']             = 'Дозволе за';
$lang['page']                  = 'Страница';
$lang['namespace']             = 'Именски простор';
$lang['btn_select']            = 'Одабери';
$lang['p_user_id']             = 'Корисник <b class="acluser">%s</b> тренутно има следеће дозволе за ову страницу <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_user_ns']             = 'Корисник <b class="acluser">%s</b> тренутно има следеће дозволе за овај именски простор <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_id']            = 'Чланови групе <b class="acluser">%s</b> тренутно имају следеће дозволе за ову страницу <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_group_ns']            = 'Чланови групе <b class="acluser">%s</b> тренутно имају следеће дозволе за овај именски простор <b class="aclpage">%s</b>: <i>%s</i>.';
$lang['p_choose_id']           = 'Молим Вас <b>унесите корисника или групу</b> у формулар изнад да бисте приказали или изменили дозволе за страницу <b class="aclpage">%s</b>.';
$lang['p_choose_ns']           = 'Молим Вас <b>унесите корисника или групу</b> у формулар изнад да бисте приказали или изменили дозволе за именски простор <b class="aclpage">%s</b>.';
$lang['p_inherited']           = 'Напомена: Ове дозволе се не постављају експлицитно већ само тамо где се не сударају са осталим групама или вишем иманском простору.';
$lang['p_isadmin']             = 'Напомена: Одабран корисник или група има увек пуне дозволе јер је постављен за суперкорисника.';
$lang['p_include']             = 'Више дозволе укључују ниже. Дозволе одавања, слања и брисања ће бити примењене само на именске просторе, не и на стране.';
$lang['current']               = 'Тренутна правила проступа';
$lang['where']                 = 'Страница/Именски простор';
$lang['who']                   = 'Корисник/Група';
$lang['perm']                  = 'Дозволе';
$lang['acl_perm0']             = 'Ништа';
$lang['acl_perm1']             = 'Читање';
$lang['acl_perm2']             = 'Измена';
$lang['acl_perm4']             = 'Прављење';
$lang['acl_perm8']             = 'Слање';
$lang['acl_perm16']            = 'Брисање';
$lang['acl_new']               = 'Додај нови унос';
$lang['acl_mod']               = 'Измени унос';
